@@ -1,10 +1,11 @@
 /*
 
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -27,12 +28,13 @@ class KXMLGUIClient;
 class KActionCollection;
 
 namespace MailCommon {
+class MailCommonSettings;
 class MAILCOMMON_EXPORT FavoriteCollectionWidget : public Akonadi::EntityListView
 {
     Q_OBJECT
 public:
-    explicit FavoriteCollectionWidget(KXMLGUIClient *xmlGuiClient, QWidget *parent = nullptr);
-    ~FavoriteCollectionWidget();
+    explicit FavoriteCollectionWidget(MailCommon::MailCommonSettings *settings, KXMLGUIClient *xmlGuiClient, QWidget *parent = nullptr);
+    ~FavoriteCollectionWidget() override;
 
     void readConfig();
     void updateMode();
@@ -47,13 +49,19 @@ protected Q_SLOTS:
 
 protected:
     void paintEvent(QPaintEvent *) override;
+    void dragEnterEvent(QDragEnterEvent *event) override;
+    void dragMoveEvent(QDragMoveEvent *event) override;
+    void dropEvent(QDropEvent *event) override;
+    void startDrag(Qt::DropActions) override;
 
     void mousePressEvent(QMouseEvent *e) override;
 Q_SIGNALS:
     void newTabRequested(bool);
 
 private:
+    bool acceptEvent(QDropEvent *event) const;
     void createMenu(KActionCollection *ac);
+
     class Private;
     Private *const d;
 };
